<?php

// $Id

/**
 * @file
 *  test the storage driver abstraction layer. This should cover
 *  test mountpoint as well. 
 * @todo: create a test using fileapi_storage driver invoke
 *        to test the mount point abstraction.
 * @todo: create a test that explicity tests all mountpoint/repositories
 *        
 * @todo
 *   split up cases into multiple methods.
 * @todo
 *    read/write file tests
 * @todo
 *    readdir tests
 */

class FileapiDriver extends DrupalTestCase {
  function get_info() {

    return array(
      'name' => t('driver tests object'),
      'desc' => t('This does nothing. I can\'t seem to make simpletest not notice it.'),
      'group' => 'filesystem component tests'
    );
  }


  function _testDriver($driver, $settings) {
    #test initial touch.
    $target['settings'] = $settings;
    $target['path'] = '/test.file.txt'; 
    $result = fileapi_invoke($driver, 'touch', $target); 
    $this->assertTrue($result,'test: storagedriver_php_touch('. $target['path'] .')');

    #is file result of touch test
    $result = fileapi_invoke($driver, 'is_file', $target); 
    $this->assertTrue($result,'test: is_file('.$path.')');
    drupal_set_message('removing path: '.$path); 
    #test rm file
    $result = fileapi_invoke($driver, 'remove', $target); 
    $this->assertTrue($result,'test remove: remove('.$path.')');

    #inverted is_file test... hopefully non file garbage path.
    $result = fileapi_invoke($driver, 'is_file', $target); 
    $this->assertFalse($result,'test against non-existant file: is_file('.$path.')');

    #test if a known dir is a file. Expect False.
    $target['path'] =  '/..';
    $result = fileapi_invoke($driver, 'is_file', $target); 
    $this->assertFalse($result,'test against known dir: is_file('.$path.')');

    #create hopefully non-existant dir.
    $target['path'] = '/testMkDir';
    $result = fileapi_invoke($driver, 'mkdir', $target); 
    $this->assertTrue($result, 'mkdir: ');

    #known dir path
    $result = fileapi_invoke($driver, 'is_dir', $target); 
    $this->assertTrue($result, 'is_dir: ');

    #remove our now existant dir
    $result = fileapi_invoke($driver, 'rmdir', $target); 
    $this->assertTrue($result, 'rmdir');
  
    #clean up stat cache
    clearstatcache(); 

    #test is_dir. 
    $result = fileapi_invoke($driver, 'is_dir', $target); 
    $this->assertFalse($result,'inverted is_dir');

    #test touch before copy & move function
    $target['path'] =   '/test.file.txt';
    $result = fileapi_invoke($driver, 'touch', $target); 
    $this->assertTrue($result,'test create file before copy & move: touch('.$path.')');

    #test copy.
    $dst =  $target;
    $dst['path'] = '/copyof.test.file.txt';
    $result = fileapi_invoke($driver, 'copy', $target, $dst); 
    $this->assertTrue($result,'test: copy('. $target['path'] .','. $dst['path'] .')');

    #verify copy
    $result = fileapi_invoke($driver, 'is_file',  $dst); 
    $this->assertTrue($result,'test verifying copy result: is_file('. $dst['path'] .')');

    #remove copy
    $result = fileapi_invoke($driver, 'remove', $dst); 
    $this->assertTrue($result,'test cleanup move result: rm('. $dst['path'] .')');

    #test move.
    $dst['path'] =  '/moved.test.file.txt';
    $result = fileapi_invoke($driver, 'move', $target, $dst); 
    $this->assertTrue($result,'test: move('. $target['path'] .','. $dst['path'] .')');

    #verify move.
    $result = fileapi_invoke($driver, 'is_file', $dst); 
    $this->assertTrue($result,'test verifying move result: is_file('. $dst['path'] .')');

    #verify src was removed move.
    $result = fileapi_invoke($driver, 'is_file', $target); 
    $this->assertFalse($result,'test verifying orignal was removed on move operation: is_file('. $target['path'] .')');

    #cleanup after move
    $result = fileapi_invoke($driver, 'remove', $dst); 
    $this->assertTrue($result,'test cleanup move result: rm('.$movedst.')');
    
    #test exists for a dir
    $target['path'] =   '/.';
    $result = fileapi_invoke($driver, 'exists', $target); 
    $this->assertTrue($result,'test exists dir: exists('. $target['path'] .')');

    #test inverted exists for a file.
    $target['path'] =   '/ia;ksdjf;kasd;kjdjkfk;alskdjf;lkd;fk;aksjdf;lkindex.php';
    $result = fileapi_invoke($driver, 'exists', $target); 
    $this->assertFalse($result,'test exists file: exists('. $target['path'] .')');
  }

}


?>
