<?php
// $Id: fileapi.drivers.inc,v 1.1 2006/09/27 07:40:54 dopry Exp $
 
/**
 * @file
 * 
 * provides a system level api for file activity, 
 * exclusive of database interaction.
 *
 * @todo
 *    implement write to file function(s).
 */

/** 
 * touch a file
 * @param $file
 *    array definition of file to touch, or a path to be.
 * @return bool
 */
function fileapi_touch($path) {
  $target = fileapi_parse_path($path);
  return fileapi_invoke($target['driver'], 'touch', $target);
}

/** 
 * test if a file array is a file.
 * @param $file
 *    file array
 * @return bool
 */
function fileapi_is_file($path) {
  $target = fileapi_parse_path($path);
  return fileapi_invoke($target['driver'], 'is_file', $target);
}

/** 
 * test if a file array is a directory.
 * @param $file
 *    file array
 * @return bool
 */
function fileapi_is_dir($file) {
  $target = fileapi_parse_path($file);
  return fileapi_invoke($target['driver'], 'is_dir', $target);
}

/** 
 * remove a directory.
 * @param $file
 *    file array
 * @return bool
 */
function fileapi_rmdir($file) {
  if (fileapi_is_dir($file)) {
    $target = fileapi_parse_path($file);
    return fileapi_invoke($target['driver'], 'rmdir', $target);
  } 
  return FALSE;
}

/** 
 * save an uploaded file to the local file system.
 *
 * @params key
 *    _FILES array key that identified the upload.
 * @params dst
 *    local destination path. since this function uses
 *    php's move_uploaded_file to avoid open_basedir restrictions
 *    it doesn not use a driver.
 * @return
 *    file array on success
 *    or false
 */

function fileapi_save($key, $dst) {
  if (!isset($dst)) {
    $dst = _filesystem_tmp_path();
  }
  debug_msg('fileapi_save('. $key .','. $dst .')');

  if (isset($_FILES['edit']['error'][$key])) {
    // catch upload errors;
    // @see http://php.net/manual/en/features.file-upload.errors.php
    //      for more information regarding the constants.

    switch($_FILES['edit']['error'][$key]) {
      case UPLOAD_ERR_OK:
        break;

      case UPLOAD_ERR_INI_SIZE:
        drupal_set_message(t('The file %file could not be saved, because it exceeds the maximum allowed file upload size. see max_upload_size', array('%file'=> theme('placeholder',$source))),'error');
        return FALSE;

      case UPLOAD_ERR_FORM_SIZE:
        drupal_set_message(t('The file %file could not be saved, because it exceeds the maximum allowed post size. see post_max_size', array('%file'=> theme('placeholder',$source))),'error');
        return FALSE;

      case UPLOAD_ERR_PARTIAL:
      case UPLOAD_ERR_NO_FILE:
        drupal_set_message(t('The file %file could not be saved, because the upload did not complete.', array('%file'=> theme('placeholder',$source))),'error');
        return FALSE;

      // Unknown error
      default:
        drupal_set_message(t('The file %file could not be saved. An unknown error has occurred.', array('%file'=> theme('placeholder',$source))),'error');
        return FALSE;
    }

    $file = array();
    $file['name'] = trim(basename($_FILES['edit']['name'][$key]), '.');
    $file['path'] = fileapi_unique_name($dst .'/'. trim(basename($_FILES['edit']['tmp_name'][$key])));
    $file['mime'] = $_FILES['edit']['type'][$key];
    $file['size'] = $_FILES['edit']['size'][$key];
    $file['source'] = $key;

    // Rename potentially executable files, to help prevent exploits.
    if (  (
            ( substr($file['mime'], 0, 5) == 'text/' || strpos($file['mime'], 'javascript') )
            && (substr($file['name'], -4) != '.txt')
          )
          || preg_match('/\.(php|pl|py|cgi|asp)$/i', $file['name'])
        ) {
      $file['mime'] = 'text/plain';
      $file['path'] .= '.txt';
      $file['name'] .= '.txt';
    }

    // Move uploaded files from php's upload_tmp_dir to Drupal's file temp.
    // This overcomes open_basedir restrictions for future file operations.
    if (!move_uploaded_file($_FILES['edit']['tmp_name'][$key], $file['path'])) {
      drupal_set_message(t('File upload error. Could not move uploaded file.'));
      drupal_set_message(t('Upload Error. Could not move uploaded file(%file) to destination(%destination)',array('%file' => theme('placeholder', $_FILES["edit"]["tmp_name"][$key]), '%destination' => theme('placeholder',$file['path'])))); 
      watchdog('file', t('Upload Error. Could not move uploaded file(%file) to destination(%destination)',array('%file' => theme('placeholder', $_FILES["edit"]["tmp_name"][$key]), '%destination' => theme('placeholder',$file['path'])))); 
      return FALSE;
    }
    return $file;
  }
  drupal_set_message('no files uploaded');
  return false;
}

/**
 * Copy a file.
 * 
 * @param array, $src
 *    array representing the file to be copied. (all file elements)
 *
 * @param array, $dst 
 *    file array with 'path' and 'driver' elements of destination.
 *    copy destination, can be an absolute path or a path relative to the drupal installation
 *    base directory with or without the filename.
 *
 * @return mixed
 *    file array on success.
 *    false on failure. 
 */    

function fileapi_copy($src, $dst) {
  // Test that src exists.
  //debug_msg($src, 'fileapi_copy->src'); 
  //debug_msg($dst, 'fileapi_copy->dst'); 

  if (!fileapi_exists($src)) {
    drupal_set_message(t('The selected file %file could not be copied, because the source path is invalid: %file.', array('%file' => theme('placeholder', $src['path']))), 'error');
    return FALSE;
  }
  // Make sure we recieved a full path.
  if (fileapi_is_dir($dst)) {
    $dst .= $src['name'];
  }

  //debug_msg($dst,'fileapi->corrected_path($dst)');
  $dst = fileapi_unique_name($dst);
  if ($dst === FALSE) {
    return FALSE;
  }
  // debug_msg($dst, 'fileapi_copy->fileapi_unique_name($dst)');
  // Since both src and destination use the same driver we can use the 
  // drivers native copy function.
  $srctarget = fileapi_parse_path($src);
  $dsttarget = fileapi_parse_path($dst);

  if ($srctarget['driver'] == $dsttarget['driver']) {
    if (fileapi_invoke($srctarget['driver'], 'copy', $srctarget, $dsttarget)) {
      return $dst;
    }
    else {
      // debug_msg(NULL,'invoke_copy failed');
    }
  } 
  // The source and destination are not using the same driver so we 
  // read in and write out the file to the new storage. 
  else {
    drupal_set_message('<em>copying across drivers</em>');
    $tmpfile = fileapi_fileread($srctarget);
    if (fileapi_filewrite($dsttarget, $tmpfile)) {
      fileapi_remove($srctarget);
      return TRUE;
    }
    else {
      //debug_msg(NULL,'fileread/filewrite failed');
    }
  }
  return FALSE;
}

/**
 * move a file. We use a non-destructive copy and delete procedure.
 * makes moving between storage drivers easier and simplifies code.
 *
 * @params $src
 *    a path
 * @params $dst
 *    a path
 * @return bool
 *    false on failure.
 */

function fileapi_move($src, $dst) {
  //debug_msg($src,'fileapi_move->src');
  //debug_msg($dst,'fileapi_move->dst');
  if (fileapi_copy($src, $dst)) {
    if (!fileapi_remove($src)) {
      //watchdog an error: src file not removed on move.
    }
    return TRUE;
  } 
  return FALSE;
}

/**
 * remove a file from the filesystem
 * @param $path
 *    a path
 * @return bool
 */
function fileapi_remove($path) {
  // debug_msg($file);
  if (!fileapi_exists($path)) {
    drupal_set_message(t('The selected file %file has already been removed.', array('%file' => theme('placeholder', $file['path']))), 'error');
    return TRUE;
  }
  $target = fileapi_parse_path($path);
  // replace with abstract storage driver callback
  return fileapi_invoke($target['driver'], 'remove', $target);
}


/**
 * create a directory, recursively
 * @param $path
 *    path to create.
 * @return bool
 */

function fileapi_mkdir($path) {
  // debug_msg($path,'fileapi_mkdir->path');
  // Return true if the directory already exists...
  if (fileapi_is_dir($path)) {
    drupal_set_message('path exists');
    return TRUE;
  }
  // Make sure we aren't trying to put a directory where a file alread exists.
  if (fileapi_is_file($path)) {
    drupal_set_message(t('Could not create directory %path. A file already exists by that name.', array('%path' => theme('placeholder',$file['path']))));
    return FALSE;
  }

  // Split mountpoint from path and get repository information.
  $target = fileapi_parse_path($path);
  //debug_msg($target, '$target from'. $path);
  if (fileapi_invoke($target['driver'], 'mkdir', $target)) {
    // Well we successfully made the directory so return true.
    //debug_msg($target, 'mkdir succeeds on');
    return TRUE;
  }

  // If we made it to here, and we haven't return that means that were were missing a parent
  // so recurse back towards path root.
  $parent = dirname($path);
  if (!fileapi_mkdir($parent)) {
    //debug_msg($parent, 'we failed to create'); 
    return FALSE;
  }
  //debug_msg($parent,  'parent path') ;
  // If we succeeded in making the parent.. Try yet again and return the result.
  $result =  fileapi_invoke($target['driver'], 'mkdir', $target);
  if (!$result) {
    //debug_msg($target, 'failed to create');
  }
  else {
    //debug_msg($target, 'created');
  }
  return $result;
}

/**
 *  create a unique filename 
 *
 *  @param $file
 *    file array
 *  @return 
 *    file array with a unique path. 
 */

function fileapi_unique_name($file, $replace = FILE_EXISTS_RENAME) {
  if (fileapi_exists($file)) {
    $basename = basename($file['path']);
    $directory  = dirname($file['path']);
    switch ($replace) {
      case FILE_EXISTS_RENAME:
        // Destination file already exists and we can't replace is so we try and
        // and find a new filename.
        if ($pos = strrpos($basename, '.')) {
          $name = substr($basename, 0, $pos);
          $ext = substr($basename, $pos);
        }
        else {
          $name = $basename;
        }
        //debug_msg($name);
        $counter = 0;
        do {
          $file['path'] = $directory .'/'. $name .'_'. $counter++ . $ext;
        } while (fileapi_exists($file));
        break;

      case FILE_EXISTS_ERROR:
        drupal_set_message(t('The selected file %file could not be copied, because a file by that name already exists in the destination.', array('%file' => theme('placeholder', $file['path']))), 'error');
        return FALSE;
    }
  }
  return $file;
} 

function fileapi_exists($path) {
  $target = fileapi_parse_path($path);
  return fileapi_invoke($target['driver'], 'exists', $target);
}

/**
 * read the contents of a file.
 * @params array
 *   file array with a path and driver element
 * @return mixed
 *   binary data or false
 */
function fileapi_fileread($path) {
  if (fileapi_exists($path)) {
    $target = fileapi_parse_path($path);
    return fileapi_invoke($target['driver'], 'fileread', $target);
  }
  drupal_set_message('Source file does not exist.');
  return false;
}

/**
 * write data to a file.
 * @todo mode?? append, overwrite, prepend
 * @params array
 *   file array with a path and driver element
 * @params data
 *   binary file data.
 * @return bool
 */
function fileapi_filewrite($path, $data, $mode) {
  $target = fileapi_parse_path($path);
  return fileapi_invoke($target['driver'], 'filewrite', $target, $data, $mode);
}

function fileapi_size($path) {
  return filesize($path);
}

/**
 * invoke storage drivers
 * 
 * @param $driver
 *   storage driver to invoke
 * @param $function
 *   callback function to be used.
 * @param $settings
 *   storage driver settings
 * @param $mixed
 *   varies per callback.
 */
function fileapi_invoke() {
  $args = func_get_args();
  //debug_msg($args, 'fileapi_invoke');
  $driver = array_shift($args);
  $function = array_shift($args);
  $callback = 'fileapi_driver_'. $driver .'_'. $function;
  if (function_exists($callback)) {
    return call_user_func_array($callback, $args);
  }
  else {
    return FALSE;
  }
}

/**
 * @return array of available drivers
 */
function fileapi_get_storage_drivers() {
  $dir = drupal_get_path('module', 'filesystem'). '/drivers';
  $drivers = file_scan_directory($dir, '\.driver$');
  foreach ($drivers as $path => $driver) {
    $drivercache[$driver->name] = $driver->name;
  }
  return $drivercache;
}

/**
 * @return array of enabled drivers
 */
function fileapi_get_enabled_drivers() {
  $drivers = variable_get('filesystem_storage_drivers',array('php'));
  foreach($drivers as $key => $value) {
    //why?
    if ($value === 0) {
      unset($drivers[$key]);
    }
  } 
  return $drivers;
}


/**
 * get a repository record from the database. caches results.
 *
 * @param $mountpoint
 *    mountpoint to return repository data about
 *
 * @return 
 *     a repository record or the default repository.
 *     
 */
function fileapi_get_repositories($mountpoint = '') {
  static $repositories = NULL;
  if (!isset($repositories)) {
    $result = db_query('SELECT * FROM {filesystem_repositories}');
    while($row = db_fetch_array($result)) {
      $row['settings'] = unserialize($row['settings']);
      $repositories[$row['mountpoint']] = $row;
    }
  }
  if ($mountpoint) {
    return $repositories[$mountpoint];
  }
  return $repositories;
}

function fileapi_parse_path($path) {
  //debug_msg($path, 'fileapi_parse_path->path');
  // cachecheck
  static $path_cache = array();
  if (isset($path_cache[$path])) {
    return $path_cache[$path]; 
  }

  $original_path = $path;
  
  $mountpoints = fileapi_get_repositories();

  $realpath = '';
  while ($path) {

    if (isset($mountpoints[$path])) {
      $path_cache[$original_path] = array('driver' => $mountpoints[$path]['driver'], 'settings' => $mountpoints[$path]['settings'], 'path' => $realpath);
      return $path_cache[$original_path]; 
    }
    $n = strrpos($path, '/');
    $realpath = substr($path, $n). $realpath;
    $path = substr($path, 0, $n);
  }
  return FALSE;
}

/**
 * turns a path into a file.
 */
function fileapi_construct_file($file) {
  if ($file = array_merge($file, fileapi_parse_path($file['path']))) {
    return $file;
  }
  else {
    // TODO
  }
} 
